@@ -33,8 +33,7 @@ class AR(Common):
         }
 
         if self.is_bad(parsed_cmd):
-            self.dump_bad_cmd_by_id(cmd["id"], parsed_cmd)
+            self.dump_bad_cmd_id(cmd["id"])
             return
 
-        self.debug("Parsed command: {}".format(parsed_cmd))
         self.dump_cmd_by_id(cmd["id"], parsed_cmd)
