@@ -95,6 +95,8 @@ def main(args=sys.argv[1:]):
     args = parse_args(args, work_dir)
     conf = prepare_conf(args)
 
+    conf["SrcGraph.requires"] = ["CC", "CL", "CXX"]
+
     try:
         c = Clade(work_dir, args.cmds, conf, args.preset)
     except RuntimeError as e:
@@ -103,6 +105,10 @@ def main(args=sys.argv[1:]):
     if args.command and not os.path.isfile(args.cmds):
         c.intercept(args.command, use_wrappers=args.wrappers)
 
+    if not os.path.exists(args.cmds):
+        print("Something is wrong: file with intercepted commands is empty")
+        sys.exit(-1)
+
     c.parse("CDB")
 
     shutil.rmtree(work_dir)
